==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/presentation/enrollment_form_app.dart <==
import 'dart:async';
import 'dart:io';

import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/dcoupon_listener.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/user.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_accept_enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/injection_container.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form_screen.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

const int CLOSE_STATUS_CODE = 0;

class EnrollmentFormAppParams {
  final Translations translations;
  final Completer<DcouponListener> completer;
  final String externalId;
  final EnrollmentForm enrollmentForm;

  EnrollmentFormAppParams({
    this.translations,
    this.completer,
    this.externalId,
    this.enrollmentForm,
  });
}

class EnrollmentFormApp extends StatefulWidget {
  static const String routeName = '/enrollment';
  final EnrollmentFormAppParams enrollmentFormAppParams;

  const EnrollmentFormApp({
    Key key,
    this.enrollmentFormAppParams,
  }) : super(key: key);

  @override
  _EnrollmentFormAppState createState() => _EnrollmentFormAppState();
}

class _EnrollmentFormAppState extends State<EnrollmentFormApp> {
  void _closeEnrollment() {
    var dcouponListener = new DcouponListener();
    dcouponListener.code = CLOSE_STATUS_CODE;
    widget.enrollmentFormAppParams.completer.complete(dcouponListener);
  }

  void _acceptEnrollment(User updatedUser) async {
    var dcouponListener = new DcouponListener();
    final userAcceptEnrollmentForm = sl<UserAcceptEnrollmentForm>();
    final failureOrAcceptEnrollmentFormResponse =
        await userAcceptEnrollmentForm(
      UserAcceptEnrollmentFormParams(
        externalId: widget.enrollmentFormAppParams.externalId,
        user: updatedUser,
        legalDocumentsAccepted:
            widget.enrollmentFormAppParams.enrollmentForm.legalDocumentsList,
      ),
    );

    failureOrAcceptEnrollmentFormResponse.fold(
      (failure) {
        if (failure is ServerFailure) {
          dcouponListener.code = failure.httpStatus;
          dcouponListener.message =
              widget.enrollmentFormAppParams.translations.text('dcoupon_error');
          widget.enrollmentFormAppParams.completer.complete(dcouponListener);
          Navigator.of(context).pop();
        }
      },
      (acceptEnrollmentFormResponse) {
        dcouponListener.message = Constants.TRUE;
        dcouponListener.code = HttpStatus.ok;
        widget.enrollmentFormAppParams.completer.complete(dcouponListener);
        Navigator.of(context).pop();
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: EnrollmentFormScreen(
        enrollmentForm: widget.enrollmentFormAppParams.enrollmentForm,
        onCloseEnrollment: _closeEnrollment,
        onAcceptEnrollment: _acceptEnrollment,
      ),
      theme: ThemeData(
        brightness: Brightness.light,
        accentColor: DcouponColors.dCouponPrimaryOrange,
        primaryColor: DcouponColors.dCouponPrimaryOrange,
        toggleableActiveColor: DcouponColors.dCouponPrimaryOrange,
        appBarTheme: AppBarTheme(
          brightness: Brightness.light,
          color: Colors.white,
        ),
        cursorColor: DcouponColors.dCouponPrimaryOrange,
        primaryTextTheme: TextTheme(
          bodyText1: TextStyle(
            color: Colors.black,
          ),
        ),
      ),
      darkTheme: ThemeData(
        brightness: Brightness.dark,
        accentColor: DcouponColors.dCouponPrimaryOrange,
        primaryColor: DcouponColors.dCouponPrimaryOrange,
        appBarTheme: AppBarTheme(
          brightness: Brightness.dark,
          color: Colors.black,
        ),
        toggleableActiveColor: DcouponColors.dCouponPrimaryOrange,
        cursorColor: DcouponColors.dCouponPrimaryOrange,
        textSelectionHandleColor: DcouponColors.dCouponPrimaryOrange,
      ),
      localizationsDelegates: [
        const TranslationsDelegate(),
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
        GlobalCupertinoLocalizations.delegate
      ],
      supportedLocales: [
        const Locale('en', 'EN'),
        const Locale('es', 'ES'),
      ],
      debugShowCheckedModeBanner: false,
    );
  }
}

==> dcoupon_sdk_flutter_package-2.0.0.tar.gz: lib/src/presentation/enrollment_form_app.dart <==
import 'dart:async';
import 'dart:io';

import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/dcoupon_listener.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/usecases/user_accept_enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/injection_container.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form_screen.dart';
import 'package:dcoupon_sdk_flutter_package/src/themes/dark_theme.dart';
import 'package:dcoupon_sdk_flutter_package/src/themes/light_theme.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

const int CLOSE_STATUS_CODE = 0;

class EnrollmentFormAppParams {
  final Translations translations;
  final Completer<DcouponListener> completer;
  final String externalId;
  final String jwt;
  final String email;
  final EnrollmentForm enrollmentForm;

  EnrollmentFormAppParams({
    this.translations,
    this.completer,
    this.externalId,
    this.jwt,
    this.email,
    this.enrollmentForm,
  });
}

class EnrollmentFormApp extends StatefulWidget {
  static const String routeName = '/enrollment';
  final EnrollmentFormAppParams enrollmentFormAppParams;

  const EnrollmentFormApp({
    Key key,
    this.enrollmentFormAppParams,
  }) : super(key: key);

  @override
  _EnrollmentFormAppState createState() => _EnrollmentFormAppState();
}

class _EnrollmentFormAppState extends State<EnrollmentFormApp> {
  void _closeEnrollment() {
    var dcouponListener = new DcouponListener();
    dcouponListener.code = CLOSE_STATUS_CODE;
    widget.enrollmentFormAppParams.completer.complete(dcouponListener);
    Navigator.of(context).pop();
  }

  void _acceptEnrollment() async {
    var dcouponListener = new DcouponListener();
    final userAcceptEnrollmentForm = sl<UserAcceptEnrollmentForm>();
    final failureOrAcceptEnrollmentFormResponse =
        await userAcceptEnrollmentForm(
      UserAcceptEnrollmentFormParams(
        jwt: widget.enrollmentFormAppParams.jwt,
        legalDocumentsAccepted:
            widget.enrollmentFormAppParams.enrollmentForm.legalDocumentsList,
      ),
    );

    failureOrAcceptEnrollmentFormResponse.fold(
      (failure) {
        if (failure is ServerFailure) {
          dcouponListener.code = failure.httpStatus;
          dcouponListener.message =
              widget.enrollmentFormAppParams.translations.text('dcoupon_error');
          widget.enrollmentFormAppParams.completer.complete(dcouponListener);
          Navigator.of(context).pop();
        }
      },
      (acceptEnrollmentFormResponse) {
        dcouponListener.message = acceptEnrollmentFormResponse.sessionToken;
        dcouponListener.code = HttpStatus.ok;
        widget.enrollmentFormAppParams.completer.complete(dcouponListener);
        Navigator.of(context).pop();
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return false;
      },
      child: MaterialApp(
        home: Theme(
          data: Theme.of(context).brightness == Brightness.dark
              ? dCouponDarkBlack()
              : dCouponLightWhite(),
          child: EnrollmentFormScreen(
            enrollmentForm: widget.enrollmentFormAppParams.enrollmentForm,
            onCloseEnrollment: _closeEnrollment,
            onAcceptEnrollment: _acceptEnrollment,
          ),
        ),
        theme: dCouponLightWhite(),
        darkTheme: dCouponDarkBlack(),
        themeMode: Theme.of(context).brightness == Brightness.dark
            ? ThemeMode.dark
            : ThemeMode.light,
        localizationsDelegates: [
          const TranslationsDelegate(),
          GlobalMaterialLocalizations.delegate,
          GlobalWidgetsLocalizations.delegate,
          GlobalCupertinoLocalizations.delegate
        ],
        supportedLocales: [
          const Locale('en', 'EN'),
          const Locale('es', 'ES'),
        ],
        debugShowCheckedModeBanner: false,
      ),
    );
  }
}
